@@ -1,5 +1,4 @@
 import datetime
-import logging
 import imghdr
 
 import requests
@@ -11,12 +10,15 @@ from django.core.validators import MaxValueValidator, MinValueValidator
 from django.utils.translation import ugettext_lazy as _
 
 from allianceauth.eveonline.models import EveAllianceInfo, EveCorporationInfo
+from allianceauth.services.hooks import get_extension_logger
 
+from app_utils.logging import LoggerAddTag
 from eveuniverse.models import EveSolarSystem, EveType
 
+from . import __title__
 from .models import Timer
 
-logger = logging.getLogger(__name__)
+logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
 class TimerForm(forms.ModelForm):
@@ -121,7 +123,7 @@ class TimerForm(forms.ModelForm):
 
     def clean(self):
         cleaned_data = super().clean()
-        if cleaned_data["eve_solar_system_2"]:
+        if cleaned_data.get("eve_solar_system_2"):
             try:
                 solar_system = EveSolarSystem.objects.get(
                     id=cleaned_data["eve_solar_system_2"]
@@ -136,7 +138,7 @@ class TimerForm(forms.ModelForm):
                     )
                 ]
 
-        if cleaned_data["structure_type_2"]:
+        if cleaned_data.get("structure_type_2"):
             try:
                 structure_type = EveType.objects.get(
                     id=cleaned_data["structure_type_2"]
@@ -151,7 +153,7 @@ class TimerForm(forms.ModelForm):
                     )
                 ]
 
-        if cleaned_data["details_image_url"]:
+        if cleaned_data.get("details_image_url"):
             details_image_url = cleaned_data["details_image_url"]
             try:
                 r = requests.get(details_image_url, stream=True, timeout=(3.0, 10.0))
