@@ -1,7 +1,10 @@
-import logging
 from django.core.management import call_command
 from django.core.management.base import BaseCommand
 
+from allianceauth.services.hooks import get_extension_logger
+
+from app_utils.logging import LoggerAddTag
+
 from ... import __title__
 from ...constants import (
     EVE_CATEGORY_ID_STRUCTURE,
@@ -11,10 +14,9 @@ from ...constants import (
     EVE_TYPE_ID_TCU,
     EVE_TYPE_ID_IHUB,
 )
-from ...utils import LoggerAddTag
 
 
-logger = LoggerAddTag(logging.getLogger(__name__), __title__)
+logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
 class Command(BaseCommand):
